<?php 

$config['template'] = 'inline';//inline,base, mineralniy

// Google +1
$config['g1_image'] = base_url('/assets/img/logo.png');

// FaceBook
$config['fb_image'] = $config['g1_image'];

// VK button
$config['vk_image'] = $config['g1_image'];
$config['vk_noparse'] = 'true';
$config['vk_type'] = 'round';
$config['vk_text'] = 'Vk';